@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::float_epoch_always;
 
-our $DATE = '2019-01-21'; # DATE
-our $VERSION = '0.032'; # VERSION
+our $DATE = '2019-01-26'; # DATE
+our $VERSION = '0.033'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ sub meta {
     +{
         v => 4,
         prio => 50,
-        precludes => ['float_epoch', 'str_iso8601'],
+        precludes => ['float_epoch'],
     };
 }
 
@@ -60,7 +60,7 @@ Data::Sah::Coerce::perl::date::float_epoch_always - Coerce date from number (ass
 
 =head1 VERSION
 
-This document describes version 0.032 of Data::Sah::Coerce::perl::date::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
+This document describes version 0.033 of Data::Sah::Coerce::perl::date::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2019-01-26.
 
 =head1 DESCRIPTION
 
@@ -69,10 +69,6 @@ number and C<coerce_to> is "float(epoch)" (the default), then this rule does
 nothing. If C<coerce_to> is "DateTime" or "Time::Moment" then this rule
 instantiates the appropriate date object using the epoch value.
 
-To avoid confusion with number that contains "YYYY", "YYYYMM", or "YYYYMMDD",
-this coercion rule precludes the
-L<str_iso8601|Data::Sah::Coerce::perl::date::str_iso8601> coercion rule.
-
 =for Pod::Coverage ^(meta|coerce)$
 
 =head1 HOMEPAGE
