@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::datenotime::float_epoch_always;
 
-our $DATE = '2019-01-21'; # DATE
-our $VERSION = '0.032'; # VERSION
+our $DATE = '2019-01-26'; # DATE
+our $VERSION = '0.033'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,14 +24,10 @@ Data::Sah::Coerce::perl::datenotime::float_epoch_always - Coerce datenotime from
 
 =head1 VERSION
 
-This document describes version 0.032 of Data::Sah::Coerce::perl::datenotime::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
+This document describes version 0.033 of Data::Sah::Coerce::perl::datenotime::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2019-01-26.
 
 =head1 DESCRIPTION
 
-To avoid confusion with number that contains "YYYY", "YYYYMM", or "YYYYMMDD",
-this coercion rule precludes the
-L<str_iso8601|Data::Sah::Coerce::perl::date::str_iso8601> coercion rule.
-
 =for Pod::Coverage ^(meta|coerce)$
 
 =head1 HOMEPAGE
